@@ -17,7 +17,7 @@ __all__ = [
     'EditorError',
 ]
 
-__version__ = '0.4'
+__version__ = '1.0.2'
 
 
 class EditorError(RuntimeError):
@@ -36,24 +36,19 @@ def get_default_editors():
 
 def get_editor_args(editor):
     if editor in ['vim', 'gvim', 'vim.basic', 'vim.tiny']:
-        return '-f -o'
+        return ['-f', '-o']
 
     elif editor == 'emacs':
-        return '-nw'
+        return ['-nw']
 
     elif editor == 'gedit':
-        return '-w --new-window'
+        return ['-w', '--new-window']
 
     elif editor == 'nano':
-        return '-R'
+        return ['-R']
 
     else:
-        return ''
-
-
-def get_platform_editor_var():
-    # TODO: Make platform specific
-    return "$EDITOR"
+        return []
 
 
 def get_editor():
@@ -69,7 +64,7 @@ def get_editor():
             return path
 
     raise EditorError("Unable to find a viable editor on this system."
-        "Please consider setting your %s variable" % get_platform_editor_var())
+        "Please consider setting your $EDITOR variable")
 
 
 def get_tty_filename():
@@ -80,8 +75,7 @@ def get_tty_filename():
 
 def edit(filename=None, contents=None, use_tty=None):
     editor = get_editor()
-    args = get_editor_args(os.path.basename(os.path.realpath(editor)))
-    args = [editor] + args.split(' ')
+    args = [editor] + get_editor_args(os.path.basename(os.path.realpath(editor)))
 
     if use_tty is None:
         use_tty = sys.stdin.isatty() and not sys.stdout.isatty()
